==> datadog-api-client-1.10.0.tar.gz: datadog-api-client-1.10.0/src/datadog_api_client/v1/model/synthetics_api_test_config.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (
    ModelNormal,
    cached_property,
)


def lazy_import():
    from datadog_api_client.v1.model.synthetics_assertion import SyntheticsAssertion
    from datadog_api_client.v1.model.synthetics_config_variable import SyntheticsConfigVariable
    from datadog_api_client.v1.model.synthetics_test_request import SyntheticsTestRequest
    from datadog_api_client.v1.model.synthetics_api_step import SyntheticsAPIStep

    globals()["SyntheticsAssertion"] = SyntheticsAssertion
    globals()["SyntheticsConfigVariable"] = SyntheticsConfigVariable
    globals()["SyntheticsTestRequest"] = SyntheticsTestRequest
    globals()["SyntheticsAPIStep"] = SyntheticsAPIStep


class SyntheticsAPITestConfig(ModelNormal):

    validations = {}

    @cached_property
    def openapi_types():
        lazy_import()
        return {
            "assertions": ([SyntheticsAssertion],),
            "config_variables": ([SyntheticsConfigVariable],),
            "request": (SyntheticsTestRequest,),
            "steps": ([SyntheticsAPIStep],),
        }

    attribute_map = {
        "assertions": "assertions",
        "config_variables": "configVariables",
        "request": "request",
        "steps": "steps",
    }

    read_only_vars = {}

    def __init__(self, *args, **kwargs):
        """
        Configuration object for a Synthetic API test.

        :param assertions: Array of assertions used for the test. Required for single API tests.
        :type assertions: [SyntheticsAssertion], optional

        :param config_variables: Array of variables used for the test.
        :type config_variables: [SyntheticsConfigVariable], optional

        :param request: Object describing the Synthetic test request.
        :type request: SyntheticsTestRequest, optional

        :param steps: When the test subtype is `multi`, the steps of the test.
        :type steps: [SyntheticsAPIStep], optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(SyntheticsAPITestConfig, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self

==> datadog-api-client-1.11.0.tar.gz: datadog-api-client-1.11.0/src/datadog_api_client/v1/model/synthetics_api_test_config.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


def lazy_import():
    from datadog_api_client.v1.model.synthetics_assertion import SyntheticsAssertion
    from datadog_api_client.v1.model.synthetics_config_variable import SyntheticsConfigVariable
    from datadog_api_client.v1.model.synthetics_test_request import SyntheticsTestRequest
    from datadog_api_client.v1.model.synthetics_api_step import SyntheticsAPIStep

    globals()["SyntheticsAssertion"] = SyntheticsAssertion
    globals()["SyntheticsConfigVariable"] = SyntheticsConfigVariable
    globals()["SyntheticsTestRequest"] = SyntheticsTestRequest
    globals()["SyntheticsAPIStep"] = SyntheticsAPIStep


class SyntheticsAPITestConfig(ModelNormal):
    @cached_property
    def openapi_types(_):
        lazy_import()
        return {
            "assertions": ([SyntheticsAssertion],),
            "config_variables": ([SyntheticsConfigVariable],),
            "request": (SyntheticsTestRequest,),
            "steps": ([SyntheticsAPIStep],),
        }

    attribute_map = {
        "assertions": "assertions",
        "config_variables": "configVariables",
        "request": "request",
        "steps": "steps",
    }

    def __init__(self, *args, **kwargs):
        """
        Configuration object for a Synthetic API test.

        :param assertions: Array of assertions used for the test. Required for single API tests.
        :type assertions: [SyntheticsAssertion], optional

        :param config_variables: Array of variables used for the test.
        :type config_variables: [SyntheticsConfigVariable], optional

        :param request: Object describing the Synthetic test request.
        :type request: SyntheticsTestRequest, optional

        :param steps: When the test subtype is `multi`, the steps of the test.
        :type steps: [SyntheticsAPIStep], optional
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(SyntheticsAPITestConfig, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
